@@ -14,6 +14,7 @@ impl From<Row> for TypeDef {
 }
 
 impl TypeDef {
+    #[must_use]
     pub fn with_generics(mut self) -> Self {
         self.generics = self.generic_params().map(|generic| ElementType::GenericParam(generic.name().to_string())).collect();
         self
@@ -494,7 +495,9 @@ impl TypeDef {
     }
 
     pub fn has_flags(&self) -> bool {
-        self.has_attribute("FlagsAttribute")
+        // Win32 enums use the Flags attribute. WinRT enums don't have the Flags attribute but are paritioned merely based
+        // on whether they are signed.
+        self.has_attribute("FlagsAttribute") || self.underlying_type() == ElementType::U32
     }
 
     pub fn is_exclusive(&self) -> bool {
