@@ -1,6 +1,8 @@
 use super::*;
 pub use std::collections::BTreeMap;
 
+// TODO: remove all include/dependency tracking logic from reader
+
 #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd)]
 pub enum TypeInclude {
     Full,
@@ -35,7 +37,7 @@ impl TypeTree {
     }
 
     pub fn features(&self, features: &mut BTreeSet<&'static str>, keys: &mut std::collections::HashSet<Row>) {
-        self.types.values().map(|entry| entry.def.iter()).flatten().for_each(|def| def.features(features, keys));
+        self.types.values().flat_map(|entry| entry.def.iter()).for_each(|def| def.features(features, keys));
     }
 
     pub fn insert_namespace(&mut self, namespace: &'static str, pos: usize) -> &mut Self {
